%global major_ver 16
%global gm_state_dir %{_sharedstatedir}/gnumed
%global gm_server_dir %{gm_state_dir}/server

Name:		gnumed-server
Version:	%{major_ver}.14
Release:	1%{?dist}
Summary:	The GNUmed back end server
%if 0%{?rhel}
Group:		Applications/Productivity	
%endif
License:	GPLv2+
URL:		http://wiki.gnumed.de/
Source0:	http://www.gnumed.de/downloads/server/v%{major_ver}/%{name}.%{version}.tgz
BuildArch:  noarch

Requires: python
Requires: python-psycopg2
# bootstrap requires files from client package
Requires: gnumed
Requires: mailx
Requires: bzip2
Requires: gnupg2
Requires: openssl
Requires: postgresql
Requires: rsync
Requires: mx

%description
The GNUmed project builds an open source Electronic Medical Record. 
It is developed by a handful of medical doctors and programmers from 
all over the world. It can be useful to anyone documenting the health 
of patients, including but not limited to doctors, physical therapists, 
occupational therapists.

%prep
%setup -q -n gnumed-server.%{version}

%build

%install
pushd server

#Copy to %%{gm_server_dir}
mkdir -p %{buildroot}%{gm_server_dir}
ln -s %{gm_server_dir} %{buildroot}%{gm_state_dir}/Gnumed
for dirent in bootstrap pycommon sql __init__.py;
do
  cp -pr $dirent %{buildroot}%{gm_server_dir}/
done
echo "%{version}" > %{buildroot}%{gm_server_dir}/version.txt

# silcence bootstrap process by setting interactive to 'no' and set 'gm-dbo' as default password
for conffile in `find %{buildroot}/%{gm_server_dir}/bootstrap -maxdepth 1 -type f -name \*.conf` ; do \
   sed -i.bak1 's/^\(interactive[[:space:]]*=[[:space:]]*\)yes/\1no/' "$conffile" ; \
   sed -i.bak 's/^\(password[[:space:]]*=[[:space:]]*\)/\1 gm-dbo/' "$conffile" ; \
done


#copy config files to /etc
mkdir -p %{buildroot}%{_sysconfdir}/gnumed
for conf in `ls etc/gnumed/*.conf.example`; 
    do mv $conf `echo $conf|sed 's/.example//'`; 
done
cp -p -r etc/gnumed/*.conf %{buildroot}%{_sysconfdir}/gnumed

#create .gz files and copy them to mandir
mkdir -p %{buildroot}%{_mandir}/man8/
mkdir -p %{buildroot}%{_mandir}/man1/

for man in `ls doc/*.*`; \
    do gzip $man; \
done
cp -p doc/*.8.gz %{buildroot}%{_mandir}/man8
cp -p doc/*.1.gz %{buildroot}%{_mandir}/man1


#remove .sh extensions
#copy all scripts to bin dir
mkdir -p %{buildroot}%{_bindir}
rename ".sh" "" *.sh
cp gm-* %{buildroot}%{_bindir}


popd  


%files
%doc server/GnuPublicLicense.txt server/doc/README server/doc/schema
%{gm_state_dir}
%{_bindir}/gm-*
%{_mandir}/man8/gm-*
%{_mandir}/man1/gm-*
%config(noreplace) %{_sysconfdir}/gnumed/*.conf

%changelog
* Fri Jun  1 2012 Michel Salim <salimma@fedoraproject.org> - 16.14-1
- Update to v16.14
- Revert to installing to default directories; gnumed-server depends on
  gnumed client anyway, and installs symlinks assuming the default
  directory depth
- Update license field

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 15.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild


* Tue Jun 07 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 15.5-2
- Fixing backup-file-in-package.

* Tue Jun 07 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 15.5-1
- New upstream release
- PostgreSQL provides PostgreSQL-client and PostgreSQL-filedump. 
- No need to include them explicitly.

* Sun May 29 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.8-1
- New upstream release.
- Correcting spec based on review.

* Sun Feb 27 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.7-1
- New upstream release
- Added mx as dependency
- Fixing file permission for bindir, mandir

* Sun Feb 27 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.6-2
- Whole lot of fixes the spec file.

* Wed Jan 12 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.6-1
- New upstream release.

* Sun Jan 02 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.5-1
- Initial packaging based on Sebastian Hilbert's unofficial package for F13.
 
